@@ -1,5 +1,5 @@
 # from canalyst_candas.candas import FormulaTree, FuncMusic, Model, ModelMap, ModelSet
-from canalyst_candas.candas import FuncMusic, Model, ModelMap, ModelSet
+from canalyst_candas.candas import FuncMusic, Model, ModelMap, ModelSet, Chart
 import canalyst_candas.version as version
 
 __version__ = version.__version__
