@@ -402,6 +402,10 @@ def regress_dataframe(df, y_col, x_col, y_filter, sort_col="", n=24, z_score=Fal
 
 def get_earnings_and_prices(ticker, index_ticker):
     df_earnings = get_earnings_dates(ticker)
+    if df_earnings.shape[0] == 0:
+        print("No earnings data for " + ticker)
+        return None
+
     df_prices = get_price_data(
         ticker,
         reset=True,
@@ -447,51 +451,92 @@ def get_earnings_and_prices(ticker, index_ticker):
 
 
 def regress_dataframe_groups(
-    df_data, y_name="alpha_10_day", return_grouped=True, n_periods=12
+    df_data, y_name="", return_grouped=True, n_periods=12, regression_warnings=False
 ):
+    regression_warning = {}
 
-    # return df_data
+    max_time_period = df_data["period_end_date"].max()
+
+    period_names = list(
+        df_data.groupby("period_name")
+        .first()
+        .sort_values("period_end_date")
+        .reset_index()
+        .tail(n_periods)["period_name"]
+    )
+
+    warnings.filterwarnings("ignore", category=RuntimeWarning)
+    df_data = df_data.sort_values(["time_series_name", "period_end_date"])
     df_data = df_data[df_data[y_name].notna()]
     df_data = df_data[df_data["value"].notna()]
 
     def extract_lr(x, y_name):
-        Y = x[y_name].astype(float).tail(n_periods)
-        y_len = Y.shape[0]
+        test_time_period = x["period_end_date"].max()
+        if test_time_period != max_time_period:
+            time_series_name = x.iloc[0]["time_series_name"]
+            regression_warning[time_series_name] = [
+                "Time series ends at " + str(test_time_period)
+            ]
+            return None
 
-        X = x[["value"]].tail(n_periods)
+        x = x.loc[x["period_name"].isin(period_names)]
+        x = x[x["value"].notna()]
+        if x.shape[0] < n_periods and x.shape[0] > 0:
+            time_series_name = x.iloc[0]["time_series_name"]
+            regression_warning[time_series_name] = [
+                "Time series has " + str(x.shape[0]) + " periods"
+            ]
+        if x.shape[0] == 0:
+            return None
 
-        X = ssm.add_constant(X)
-        X = X.astype(float)
+        model = smf.ols(formula="value ~ " + y_name, data=x)
+        rres = model.fit()
 
-        model = ssm.OLS(Y, X).fit()
-        preds = model.predict(X)
-
-        x["preds"] = preds
-        x["rsquared"] = model.rsquared
+        x["intercept"] = rres.params[0]
+        x["n_periods"] = x.shape[0]
+        x["rsquared"] = rres.rsquared
+        x["slope"] = rres.params[1]
 
         return pd.DataFrame(x)
 
     grouped = df_data.groupby("time_series_name")  # group by each time series name
-    grouped = grouped.apply(
-        lambda x: extract_lr(x, y_name)
-    )  # apply the model to the dataframe groups
+    grouped = grouped.apply(lambda x: extract_lr(x, y_name))
+
+    if regression_warning and regression_warnings:
+        print("Regression warning:")
+        print(pd.DataFrame.from_dict(regression_warning, orient="index"))
+
     if return_grouped == True:
-        df_output = (
-            grouped.reset_index()
-            .groupby(["time_series_name", "category"])
-            .mean()
-            .reset_index()
-            .sort_values("rsquared", ascending=False)
-        )
-        return df_output[
-            [
-                "name_index",
-                "time_series_description",
-                "time_series_name",
-                "category",
-                "rsquared",
+        try:
+            df_output = (
+                grouped.reset_index(drop=True)
+                .groupby(
+                    [
+                        "name_index",
+                        "time_series_description",
+                        "time_series_name",
+                        "category",
+                    ]
+                )
+                .mean()
+                .reset_index()
+                .sort_values("rsquared", ascending=False)
+            )
+            # df_output = df_output.loc[df_output["n_periods"] >= n_periods]
+            return df_output[
+                [
+                    "name_index",
+                    "time_series_description",
+                    "time_series_name",
+                    "category",
+                    "rsquared",
+                    "slope",
+                    "intercept",
+                    "n_periods",
+                ]
             ]
-        ]
+        except:
+            print("Regression error")
     else:
         return grouped
 
@@ -690,97 +735,6 @@ def regress_dataframe_time_series_groups(
     return df
 
 
-def regress_dataframe_groups(
-    df_data, y_name="", return_grouped=True, n_periods=12, regression_warnings=False
-):
-    regression_warning = {}
-
-    max_time_period = df_data["period_end_date"].max()
-
-    period_names = list(
-        df_data.groupby("period_name")
-        .first()
-        .sort_values("period_end_date")
-        .reset_index()
-        .tail(n_periods)["period_name"]
-    )
-
-    warnings.filterwarnings("ignore", category=RuntimeWarning)
-    df_data = df_data.sort_values(["time_series_name", "period_end_date"])
-    df_data = df_data[df_data[y_name].notna()]
-    df_data = df_data[df_data["value"].notna()]
-
-    def extract_lr(x, y_name):
-        test_time_period = x["period_end_date"].max()
-        if test_time_period != max_time_period:
-            time_series_name = x.iloc[0]["time_series_name"]
-            regression_warning[time_series_name] = [
-                "Time series ends at " + str(test_time_period)
-            ]
-            return None
-
-        x = x.loc[x["period_name"].isin(period_names)]
-        x = x[x["value"].notna()]
-        if x.shape[0] < n_periods and x.shape[0] > 0:
-            time_series_name = x.iloc[0]["time_series_name"]
-            regression_warning[time_series_name] = [
-                "Time series has " + str(x.shape[0]) + " periods"
-            ]
-        if x.shape[0] == 0:
-            return None
-
-        model = smf.ols(formula="value ~ " + y_name, data=x)
-        rres = model.fit()
-
-        x["intercept"] = rres.params[0]
-        x["n_periods"] = x.shape[0]
-        x["rsquared"] = rres.rsquared
-        x["slope"] = rres.params[1]
-
-        return pd.DataFrame(x)
-
-    grouped = df_data.groupby("time_series_name")  # group by each time series name
-    grouped = grouped.apply(lambda x: extract_lr(x, y_name))
-
-    if regression_warning and regression_warnings:
-        print("Regression warning:")
-        print(pd.DataFrame.from_dict(regression_warning, orient="index"))
-
-    if return_grouped == True:
-        try:
-            df_output = (
-                grouped.reset_index(drop=True)
-                .groupby(
-                    [
-                        "name_index",
-                        "time_series_description",
-                        "time_series_name",
-                        "category",
-                    ]
-                )
-                .mean()
-                .reset_index()
-                .sort_values("rsquared", ascending=False)
-            )
-            # df_output = df_output.loc[df_output["n_periods"] >= n_periods]
-            return df_output[
-                [
-                    "name_index",
-                    "time_series_description",
-                    "time_series_name",
-                    "category",
-                    "rsquared",
-                    "slope",
-                    "intercept",
-                    "n_periods",
-                ]
-            ]
-        except:
-            print("Regression error")
-    else:
-        return grouped
-
-
 def rolling_r_squared(
     df_data, time_series_name, window, y_name="alpha_10_day", plot=False
 ):
