@@ -1,6 +1,7 @@
 """
 Utilities module
 """
+from enum import Enum
 from typing import Dict
 import pandas as pd
 from python_graphql_client import GraphqlClient
@@ -21,6 +22,7 @@ from openpyxl import load_workbook, styles
 import datetime
 import csv
 from canalyst_candas.version import __version__ as version
+import pickle
 
 from canalyst_candas.configuration.config import Config, resolve_config
 import urllib3
@@ -28,6 +30,7 @@ import urllib3
 urllib3.disable_warnings()
 
 
+EQUITY_MODEL_URL = "api/equity-model-series/{csin}/equity-models/{version}/"
 CSIN_URL = "api/equity-model-series/?company_ticker_bloomberg={ticker}"
 PERIODS_URL = (
     "api/equity-model-series/{csin}/equity-models/{version}/historical-periods/"
@@ -41,6 +44,13 @@ SCENARIO_URL_FORECAST = (
 HISTORICAL_PERIODS_TO_FETCH = 24
 
 
+class CsvDataKeys(Enum):
+    FORECAST_DATA = "forecast-data"
+    HISTORICAL_DATA = "historical-data"
+    NAME_INDEX = "name-index"
+    MODEL_INFO = "model-info"
+
+
 def set_api_key(key, key_file_path):
     """
     Loads API key from path
@@ -149,8 +159,7 @@ class Getter:
 
         z = zipfile.ZipFile(buffer)
         body = z.open(z.namelist()[0]).read().decode("utf-8")
-        df = pd.read_csv(io.StringIO(body), low_memory=False)
-        return df
+        return body
 
     def get_csv_from_s3(self, file_name):
         """
@@ -166,15 +175,37 @@ class Getter:
             return None
         return df
 
-    def get_file(self, ticker, type):
+    def get_pickle_from_s3(self, file_name):
+
+        """
+        Get CSV from S3
+        """
+        try:
+            csv_obj = self.s3_client.get_object(Bucket="candas", Key=file_name)
+            body = csv_obj["Body"].read()
+            df = pickle.loads(body)
+        except:
+            return None
+        return df
+
+    def get_file(self, ticker, type):  # returns a dataframe
         """
         Gets ticker file from S3
 
         Uses local filesystem if no file found on S3
         """
         file_ticker = ticker.split(" ")[0]
-        path_name = f"DATA/{file_ticker}/{ticker}_{type}.csv"
-        df = self.get_csv_from_s3(path_name)
+
+        path_name = (
+            f"DATA/{file_ticker}/{ticker}_{type}.pickle"  # first try pickel on s3
+        )
+        df = self.get_pickle_from_s3(path_name)
+
+        if df is None:
+            path_name = (
+                f"DATA/{file_ticker}/{ticker}_{type}.csv"  # if no pickel, try csv on s3
+            )
+            df = self.get_csv_from_s3(path_name)
 
         if df is None:
             if path.exists(f"{path_name}"):
@@ -192,6 +223,81 @@ class Getter:
         return df
 
 
+def get_data_set_from_mds(
+    csv_data_key, csin, model_version, auth_headers, log, mds_host=settings.MDS_HOST
+):
+    """
+    Pulls a CSV file from the MDS at the equity-model endpoint and returns it in a dataframe.
+
+    Different types of CSVs are available, listed in the CsvDataKeys enum.
+    """
+    url_candidates = _get_data_set_urls_from_mds(
+        csin, model_version, auth_headers, log, mds_host
+    )
+    url = _get_data_set_csv_url(url_candidates, csv_data_key.value, log)
+
+    if url is None:
+        return
+
+    response = get_request(url, auth_headers)
+    csv_string = response.content.decode("utf-8")
+    df = pd.read_csv(StringIO(csv_string))
+    return df
+
+
+def _get_data_set_csv_url(
+    csv_url_candidates,
+    csv_data_type,
+    log,
+):
+    """
+    Gets the url that matches the given 'csv_data_type' from the list of 'csv_url_candidates'
+    """
+    csv_to_download = [
+        candidate for candidate in csv_url_candidates if csv_data_type in candidate
+    ]
+
+    if not csv_to_download or len(csv_to_download) != 1:
+        log.write(
+            f"Candas: Error with retrieving the '{csv_data_type}' URL from the list '{csv_url_candidates}'."
+        )
+        return
+
+    return csv_to_download[0]
+
+
+def _get_data_set_urls_from_mds(
+    csin, model_version, auth_headers, log, mds_host=settings.MDS_HOST
+):
+    """
+    Get's the candascsvdata_set list from the equity model instance endpoint.
+
+    Since it's simply a wrapper around the MDS, it shouldn't require automated testing.
+    """
+    url = f"{mds_host}/{EQUITY_MODEL_URL.format(csin=csin, version=model_version)}"
+
+    try:
+        response = get_request(url, auth_headers)
+        response.raise_for_status()
+    except requests.RequestException as ex:
+        # log an error that the csv dataset doesn't exist
+        log.write(
+            f"Candas: Error when making a request to '{url}'. " f"Exception: {ex}."
+        )
+        return []
+
+    if response.ok:
+        csv_data_set_urls = response.json().get("candascsvdata_set")
+    else:
+        log.write(
+            f"Candas: Error when hitting '{url}'. "
+            f"Status code: {response.status_code}. Response: {response.text}."
+        )
+        csv_data_set_urls = []
+
+    return csv_data_set_urls
+
+
 def save_guidance_csv(df, ticker, filename):
     """
     Save guidance CSV
@@ -1110,6 +1216,10 @@ def mrq_df(df):
 
 def pivot_df(df, mrq_notation):
 
+    df["period_name_sorted"] = np.where(
+        df["period_name_sorted"].isna(), df["period_name"], df["period_name_sorted"]
+    )
+
     if mrq_notation == True:
         df = mrq_df(df)
         return df
